
============
Contributing
============

Contributions are welcome. You can contribute in many ways:

Reporting an issue
~~~~~~~~~~~~~~~~~~

Report an issue on `GitHub <https://github.com/lsst-sqre/kafka-connect-manager/issues>`_.

If you are reporting an issue, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the issue.

Pull Request Guidelines
~~~~~~~~~~~~~~~~~~~~~~~

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests.
2. If the pull request adds functionality, the docs should be updated.
3. The pull request should work for Python 3.


Send Feedback
~~~~~~~~~~~~~

The best way to send feedback is to file an `issue <https://github.com/lsst-sqre/kafka-connect-manager/issues>`_.

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is an open-source project, and that contributions
  are welcome :)
